//
// LightCurveMaker.cc
//
// Authors:  Richard Saxton (VEGA/ESA)
//           ESA XMM SOC
//
// Description: Creates a spectrum using evselect
//
#include <Tracer.h>
#include <metatask.h>
#include <errstr.h>
#include <param.h>
#include <Dal.h>
#include <evselect.h>

#include "LightCurveMaker.h"

LightCurveMaker::LightCurveMaker(string lcurvefile, 
                             DatafileAttributes * timeAttributes,
                             string expression, double timebin) : 
_lcurvefile(lcurvefile),
_timebin(timebin)
{
  PROC;

   /* Set up the parameters for calling evselect */
    openParameters("evselect");

   /* Ideally the selection expression should contain just a source
      spatial region. Everything else is defaulted here */

   /* Set the variable parameters */
    setParameter("rateset",_lcurvefile);
    setParameter("table",timeAttributes->datafile());

   /* Set the pattern and flag selection depending on instrument */
    switch (timeAttributes->instrumentID())
    {
    case Xmm::EMOS1 :
    case Xmm::EMOS2 :
      {
        _pattexp="&&(PATTERN<=12)";
        _flagexp="&&(#XMMEA_EM)";
        break;
      }
    case Xmm::EPN :
      {
        _pattexp="&&(PATTERN<=4)";
        _flagexp="&&(FLAG==0)";
        break;
      }
    default:
      errstr << "Dont recognise the instrument "<<_instr
             << Sas::error("invalidInstrument");
    }

    /* Set the required timebin size */
    setParameter("timebinsize",_timebin);

    /* Add the flag and pattern selection into the evselect expression. 
       If a pattern selection already exists then this will not have 
       any effect with current settings */ 

    setParameter("expression",expression+_pattexp+_flagexp);
       
  /* Set the other parameters */
    setParameter("withfilteredset",false);
    setParameter("keepfilteroutput",false);
    setParameter("flagcolumn","EVFLAG");
    setParameter("flagbit",-1);
    setParameter("filtertype","expression");
    setParameter("writedss",true);          
    setParameter("cleandss",false);          
    setParameter("updateexposure",true);          
    setParameter("filterexposure",true);          
    setParameter("timecolumn","TIME");
    setParameter("withzcolumn",false);
    setParameter("withspectrumset",false);
    setParameter("withspecranges",false);
    setParameter("withrateset",true);
    setParameter("maketimecolumn",true);
    setParameter("makeratecolumn",true);
    setParameter("withhistogramset",false);
    setParameter("energycolumn","PI");

  /* Copy optional time range parameters to evselect */
    setParameter("withtimeranges",booleanParameter("withtimeranges"));
    setParameter("timemin",realParameter("timemin"));
    setParameter("timemax",realParameter("timemax"));
    
  /* Now run evselect using these parameters */ 
    task(evselect);
   
  ENDPROC;
}

/* Destructor */
LightCurveMaker::~LightCurveMaker()
{
  PROC;
  ENDPROC;
}


